# Security Policy

## Supported Versions

Package is currently under active **beta** development.
While we recommend the use of the latest version, below is the list of the current supported versions :

| Version | Stage | Supported |
| ------- | ----- | --------- |
| 0.0.x   | alpha | ❌        |
| 0.1.x   | beta  | ✅        |

## Reporting a Vulnerability

If you see any vulnerability with this package, please open an 
[issue on the Github interface ...](https://github.com/Parallel-in-Time/qmat/issues),
so that is can be solved as quickly as possible by the developing community.